@@ -15,8 +15,8 @@ def run_webserver():
 
     parser.add_argument("--init-db", dest="init_db", action="store_true",
                         help="Initialize database and exit.")
-    parser.add_argument("--base-dir", dest="base_dir",
-                        help="Specify base directory.")
+    parser.add_argument("--config-file", dest="config_file",
+                        help="Specify location of configuration file.")
     parser.add_argument("--debug", dest="debug", action="store_true",
                         help="Display debugging information.")
     parser.add_argument("--logfile", dest="logfile",
@@ -30,8 +30,8 @@ def run_webserver():
     if args.logfile:
         logging.basicConfig(filename=args.logfile)
 
-    if args.base_dir:
-        Config.base_dir = args.base_dir
+    if args.config_file:
+        Config.config_file = args.config_file
 
     if args.init_db:
         DB.init_db()
